@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.19.4.45 1996/08/20 15:04:00 wessels Exp $
+ * $Id: squid.h,v 1.19.4.46 1996/08/30 22:53:34 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -137,6 +137,11 @@
 #include <syslog.h>
 #endif
 
+/* Only enable shadow password suite if both header and library exist */
+#if HAVE_SHADOW_H && HAVE_LIBSHADOW
+#include <shadow.h>
+#endif
+
 #if !defined(MAXHOSTNAMELEN) || (MAXHOSTNAMELEN < 128)
 #define SQUIDHOSTNAMELEN 128
 #else
