@@ -1,5 +1,5 @@
 /*
- * $Id: url.c,v 1.19.2.19 1996/08/12 06:33:27 wessels Exp $
+ * $Id: url.c,v 1.19.2.22 1996/08/29 16:37:05 wessels Exp $
  *
  * DEBUG: section 23    URL Parsing
  * AUTHOR: Duane Wessels
@@ -195,10 +195,13 @@ request_t *urlParse(method, url)
     char *t = NULL;
     int port;
     protocol_t protocol = PROTO_NONE;
+    int l;
     proto[0] = host[0] = urlpath[0] = login[0] = '\0';
 
-    if (strlen(url) > MAX_URL) {
-	debug(23, 0, "urlParse: URL too large (%d bytes)\n", strlen(url));
+    if ((l = strlen(url)) > MAX_URL) {
+	/* terminate so it doesn't overflow other buffers */
+	*(url + (MAX_URL >> 1)) = '\0';
+	debug(23, 0, "urlParse: URL too large (%d bytes)\n", l);
 	return NULL;
     }
     if (method == METHOD_CONNECT) {
@@ -301,3 +304,24 @@ int matchDomainName(domain, host)
 	return 1;
     return 0;
 }
+
+int urlCheckRequest(r)
+     request_t *r;
+{
+    int rc = 0;
+    switch (r->protocol) {
+    case PROTO_HTTP:
+    case PROTO_CACHEOBJ:
+	rc = 1;
+	break;
+    case PROTO_FTP:
+    case PROTO_GOPHER:
+    case PROTO_WAIS:
+	if (r->method == METHOD_GET)
+	    rc = 1;
+	break;
+    default:
+	break;
+    }
+    return rc;
+}
